@@ -32,7 +32,8 @@ UrlConfigurationDialog::UrlConfigurationDialog(QWidget *parent)
     mainLayout->addWidget(mainWidget);
     mUi.setupUi(mainWidget);
     mUi.credentialsGroup->setVisible(false);
-    mUi.password->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+    mUi.password->setRevealPasswordMode(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")) ? KPassword::RevealMode::OnlyNew
+                                                                                                           : KPassword::RevealMode::Never);
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -188,7 +189,7 @@ void UrlConfigurationDialog::onFetchButtonClicked()
         setRemoteUrl(remoteUrl() + QLatin1Char('/'));
     }
 
-    if (!remoteUrl().startsWith(QLatin1String("https://")) && !remoteUrl().startsWith(QLatin1String("http://"))) {
+    if (!remoteUrl().startsWith(QLatin1StringView("https://")) && !remoteUrl().startsWith(QLatin1StringView("http://"))) {
         setRemoteUrl(QStringLiteral("https://") + remoteUrl());
     }
 
