@@ -18,6 +18,7 @@
 #include <KGAPI/Calendar/CalendarFetchJob>
 #include <KGAPI/Tasks/TaskList>
 #include <KGAPI/Tasks/TaskListFetchJob>
+#include <KLocalization>
 #include <KMessageBox>
 #include <KWindowSystem>
 
@@ -37,7 +38,7 @@ GoogleSettingsWidget::GoogleSettingsWidget(GoogleSettings &settings, const QStri
     mainLayout->addWidget(mainWidget);
     setupUi(mainWidget);
 
-    refreshSpinBox->setSuffix(ki18np(" minute", " minutes"));
+    KLocalization::setupSpinBoxFormatString(refreshSpinBox, ki18np("%v minute", "%v minutes"));
     enableRefresh->setChecked(m_settings.enableIntervalCheck());
     refreshSpinBox->setEnabled(m_settings.enableIntervalCheck());
     refreshSpinBox->setValue(m_settings.intervalCheckTime());
