@@ -40,6 +40,11 @@ IcalDirSettingsWidget::IcalDirSettingsWidget(const KSharedConfigPtr &config, QWi
     connect(ui.kcfg_ReadOnly, &QCheckBox::toggled, this, &IcalDirSettingsWidget::validate);
 
     ui.kcfg_Path->setUrl(QUrl::fromLocalFile(IcalDirResourceSettings::self()->path()));
+    ui.kcfg_Path->setToolTip(i18nc("@info:tooltip", "A directory path or URL containing calendar files"));
+    ui.kcfg_Path->setWhatsThis(xi18nc(
+        "@info:whatsthis",
+        "Enter the path or URL to a directory whose contents should be represented by this resource. The directory will be created if it does not exist."));
+
     KLocalization::setupSpinBoxFormatString(ui.kcfg_AutosaveInterval, ki18np("%v minute", "%v minutes"));
     mManager = new KConfigDialogManager(mainWidget, IcalDirResourceSettings::self());
     ui.readOnlyLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
