@@ -84,7 +84,7 @@ using namespace Akonadi;
 using namespace QKeychain;
 
 ImapResourceBase::ImapResourceBase(const QString &id)
-    : ResourceBase(id)
+    : ResourceWidgetBase(id)
     , m_pool(new SessionPool(2, this))
     , m_settings(nullptr)
 {
@@ -130,6 +130,22 @@ ImapResourceBase::ImapResourceBase(const QString &id)
     new ImapResourceBaseAdaptor(this);
 
     QMetaObject::invokeMethod(this, &ImapResourceBase::delayedInit, Qt::QueuedConnection);
+
+    connect(this, &ImapResourceBase::reloadConfiguration, this, &ImapResourceBase::slotConfigurationChanged);
+}
+
+void ImapResourceBase::init()
+{
+    if (settings()->name().isEmpty()) {
+        if (name() == identifier()) {
+            settings()->setName(defaultName());
+        } else {
+            settings()->setName(name());
+        }
+    }
+    setActivitiesEnabled(settings()->activitiesEnabled());
+    setActivities(settings()->activities());
+    setName(settings()->name());
 }
 
 void ImapResourceBase::delayedInit()
@@ -195,18 +211,6 @@ void ImapResourceBase::updateResourceName()
     }
 }
 
-// -----------------------------------------------------------------------------
-
-void ImapResourceBase::configure(WId windowId)
-{
-    if (createConfigureDialog(windowId)->exec() == QDialog::Accepted) {
-        Q_EMIT configurationDialogAccepted();
-        reconnect();
-    } else {
-        Q_EMIT configurationDialogRejected();
-    }
-}
-
 // ----------------------------------------------------------------------------------
 
 void ImapResourceBase::startConnect(const QVariant &)
@@ -227,54 +231,6 @@ void ImapResourceBase::startConnect(const QVariant &)
     Q_UNUSED(result)
 }
 
-int ImapResourceBase::configureSubscription(qlonglong windowId)
-{
-    if (mSubscriptions) {
-        return 0;
-    }
-
-    if (!m_pool->account()) {
-        return -2;
-    }
-
-    auto showServersideSubscription = [this, windowId](const QString &password) {
-        mSubscriptions.reset(new SubscriptionDialog(nullptr, SubscriptionDialog::AllowToEnableSubscription));
-        if (windowId) {
-            mSubscriptions->setAttribute(Qt::WA_NativeWindow, true);
-            KWindowSystem::setMainWindow(mSubscriptions->windowHandle(), windowId);
-        }
-        mSubscriptions->setWindowTitle(i18nc("@title:window", "Serverside Subscription"));
-        mSubscriptions->setWindowIcon(QIcon::fromTheme(QStringLiteral("network-server")));
-        mSubscriptions->connectAccount(*m_pool->account(), password);
-        mSubscriptions->setSubscriptionEnabled(settings()->subscriptionEnabled());
-        connect(mSubscriptions.get(), &SubscriptionDialog::accepted, this, [this]() {
-            settings()->setSubscriptionEnabled(mSubscriptions->subscriptionEnabled());
-            settings()->save();
-            Q_EMIT configurationDialogAccepted();
-            reconnect();
-        });
-        connect(mSubscriptions.get(), &SubscriptionDialog::finished, this, [this]() {
-            mSubscriptions.reset();
-        });
-        mSubscriptions->show();
-    };
-
-    if (settings()->mustFetchPassword()) {
-        auto readPasswordJob = settings()->requestPassword();
-        connect(readPasswordJob, &ReadPasswordJob::finished, this, [readPasswordJob, showServersideSubscription]() {
-            if (readPasswordJob->error() != Error::NoError) {
-                return; // error handling is done in requestPassword
-            }
-            showServersideSubscription(readPasswordJob->textData());
-        });
-        readPasswordJob->start();
-    } else {
-        showServersideSubscription(settings()->password());
-    }
-
-    return 0;
-}
-
 void ImapResourceBase::onConnectDone(int errorCode, const QString &errorString)
 {
     switch (errorCode) {
@@ -727,4 +683,25 @@ void ImapResourceBase::onCollectionModifyDone(KJob *job)
     }
 }
 
+void ImapResourceBase::slotConfigurationChanged()
+{
+    const auto oldImapServer = settings()->imapServer();
+    const auto oldUserName = settings()->userName();
+
+    settings()->load();
+
+    const auto newImapServer = settings()->imapServer();
+    const auto newUserName = settings()->userName();
+
+    if (oldImapServer != newImapServer || oldUserName != newUserName) {
+        clearCache();
+    }
+
+    setActivitiesEnabled(settings()->activitiesEnabled());
+    setActivities(settings()->activities());
+    setName(settings()->name());
+
+    reconnect();
+}
+
 #include "moc_imapresourcebase.cpp"
