@@ -28,7 +28,7 @@ public:
     void setFetchMissingItemBodies(bool enabled);
 
 public Q_SLOTS:
-    void onFetchItemsWithoutBodiesDone(const QVector<qint64> &items);
+    void onFetchItemsWithoutBodiesDone(const QList<qint64> &items);
     void onReadyForNextBatch(int size);
 
 private Q_SLOTS:
@@ -61,7 +61,7 @@ private:
     void taskComplete();
 
     KIMAP::Session *m_session = nullptr;
-    QVector<qint64> m_messageUidsMissingBody;
+    QList<qint64> m_messageUidsMissingBody;
     int m_fetchedMissingBodies = -1;
     bool m_fetchMissingBodies = false;
     bool m_incremental = true;
