@@ -6,14 +6,13 @@
 
 #include "datetimeutils.h"
 
-#include "conversion/commonconversion.h"
 #include <QTimeZone>
 
 namespace Kolab
 {
 namespace DateTimeUtils
 {
-KOLAB_EXPORT std::string getLocalTimezone()
+std::string getLocalTimezone()
 {
     const auto tz = QTimeZone::systemTimeZoneId();
     return tz.toStdString();
