@@ -8,9 +8,9 @@
 
 #include "maildir_export.h"
 
+#include <Akonadi/Item>
 #include <QString>
 #include <QStringList>
-#include <item.h>
 
 class QDateTime;
 
@@ -229,7 +229,7 @@ public:
     void refreshKeyCache();
 
     /** Return the last error message string. The error might not come from the last performed operation,
-     if that was sucessful. The caller should always check the return value of the methods before
+     if that was successful. The caller should always check the return value of the methods before
      querying the last error string. */
     QString lastError() const;
 
