@@ -34,7 +34,7 @@ public:
     {
     }
 
-    ~CollectionMoveTest()
+    ~CollectionMoveTest() override
     {
         delete mStore;
         delete mDir;
@@ -408,8 +408,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -523,8 +524,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -563,8 +565,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -654,8 +657,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -893,8 +897,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -936,8 +941,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -983,8 +989,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1030,8 +1037,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1074,8 +1082,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1118,8 +1127,9 @@ void CollectionMoveTest::testMoveToMaildir()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1228,8 +1238,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1275,8 +1286,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1329,8 +1341,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1397,8 +1410,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1419,8 +1433,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1436,8 +1451,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1503,8 +1519,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1525,8 +1542,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1542,8 +1560,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1589,8 +1608,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1631,8 +1651,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1673,8 +1694,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1715,8 +1737,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1759,8 +1782,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1802,8 +1826,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1849,8 +1874,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1896,8 +1922,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1940,8 +1967,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
@@ -1984,8 +2012,9 @@ void CollectionMoveTest::testMoveToMBox()
 
     items = itemFetch->items();
     QCOMPARE((int)items.count(), 4);
-    Q_FOREACH (const Item &item, items) {
-        Q_FOREACH (const QByteArray &flag, item.flags()) {
+    for (const Item &item : std::as_const(items)) {
+        const auto flags{item.flags()};
+        for (const QByteArray &flag : flags) {
             ++flagCounts[flag];
         }
     }
