@@ -13,7 +13,8 @@
 #include "objectutils.h"
 #include "oxutils.h"
 
-#include <kio/davjob.h>
+#include <KIO/DavJob>
+#include <QDomDocument>
 
 using namespace OXA;
 
@@ -52,7 +53,9 @@ void ObjectRequestJob::davJobFinished(KJob *job)
 
     auto davJob = qobject_cast<KIO::DavJob *>(job);
 
-    const QDomDocument document = davJob->response();
+    const QByteArray ba = davJob->responseData();
+    QDomDocument document;
+    document.setContent(ba);
 
     QString errorText, errorStatus;
     if (DAVUtils::davErrorOccurred(document, errorText, errorStatus)) {
@@ -70,3 +73,5 @@ void ObjectRequestJob::davJobFinished(KJob *job)
 
     emitResult();
 }
+
+#include "moc_objectrequestjob.cpp"
